package configuration;

##############################################################################
# configuration required by all programs
##############################################################################

use constant DIE_ON_UNKNOWN_ITEM_TITLE => 1;
use constant ASK_ON_UNKNOWN_ITEM_TITLE => 2;
use constant USE_OTHER_INCOME_ON_UNKNOWN_ITEM_TITLE => 3;

# If this variable is DIE_ON_UNKNOWN_ITEM_TITLE, stop the program if an unknown PayPal item title is found.
# For Quickbooks you add an entry to the %ItemTitle2Income hash below.
# If this variable is ASK_ON_UNKNOWN_ITEM_TITLE, you'll be asked to select an account name if an unknown PayPal item title is found.
# If this variable is USE_OTHER_INCOME_ON_UNKNOWN_ITEM_TITLE, unknown PayPal item titles will be added to the $other_income or $qif_default_income_account_name account.
our $handleUnknownItemTitle = ASK_ON_UNKNOWN_ITEM_TITLE;

##############################################################################
# PayPal configuration, required for paypal2*.pl
##############################################################################

# identifier for the PayPal account
our $paypal_login = 'cabin@snowdrifters.org';
# currency abbreviation of your PayPal account
our $paypal_currency = 'USD';

# variables for the PayPal Signature API
our $paypal_username = "";
our $paypal_password = "";
our $paypal_signature= "";
our $paypal_sandbox  = 0; # valid values are 0 and 1.

##############################################################################
# QIF configuration, required for paypal2qif.pl
##############################################################################

# name of the PayPal bank account
our $qif_paypal_account_name = 'Assets:PayPal';

# name of the default Income account
our $qif_default_income_account_name = 'Income:Other Income';

# name of the Expenses account for PayPal fees
our $qif_paypal_fee_account_name = 'Expenses:PayPalFee';

##############################################################################
# Quickbooks configuration, required for paypal2iif.pl and csv2iif.pl
##############################################################################

# name of the Quickbooks PayPal account
our $paypal_account_name = 'PayPal';

# name of the Quickbooks primary checking account, where transfers from PayPal are received
our $checking_account_name = 'Wells Fargo Checking';

# name of the Quickbooks account for misc income
our $other_income = 'Other Types of Income';

# renaming rules: key is a PayPal item title, value is a Quickbooks account name
our %ItemTitle2Income = ( 'Shopping Cart' => 'Cabin Income',
			  'Racing registration' => 'Racing Income',
			  'Membership 2016' => 'Membership Dues',
			  'SnowBall 2015' => 'Special Events Income',
			);

##############################################################################
# nothing to configure beyond this point!
##############################################################################

# check configuration
die '$paypal_account_name not defined' unless length($paypal_account_name);
die '$checking_account_name not defined' unless length($checking_account_name);
die '$other_income account not configured' unless length($other_income);

die '$paypal_login not defined'unless length($paypal_login);
die '$paypal_currency is not a 3 letter abbreviation' unless length($paypal_currency) == 3;

if (length($paypal_username)==0 && length($paypal_password)==0 && length($paypal_signature)==0) {
    # ok
} elsif (length($paypal_username) < 6) {
  die "PayPal username too short, must have at least 6 characters: '$paypal_username'";
} elsif (length($paypal_password) != 16) {
  die "PayPal password must have 16 characters: '$paypal_password' has " . length($paypal_password) . " characters";
} elsif (length($paypal_signature) != 56) {
  die "PayPal signature must have 56 characters: '$paypal_signature' has " . length($paypal_signature) . " characters";
}
die "invalid \$paypal_sandbox value: $paypal_sandbox. Must be 0 or 1." unless $paypal_sandbox==0 || $paypal_sandbox==1;

die "invalid \$handleUnknownItemTitle value: $handleUnknownItemTitle" unless $handleUnknownItemTitle>=1 && $handleUnknownItemTitle<=3;
